class DATE_TIME:
    SPLITTER: str = "T"
    HOUR_TIME_FORMAT: str = "%H"
    SECONDLESS_TIME_FORMAT: str = f"{HOUR_TIME_FORMAT}:%M"
    SECOND_ZEROS_TIME_FORMAT: str = f"{SECONDLESS_TIME_FORMAT}:00"
    TIME_FORMAT: str = f"{SECONDLESS_TIME_FORMAT}:%S"
    DAY_FORMAT: str = "%d"

    ISO_DATE_FORMAT: str = f"%Y-%m-{DAY_FORMAT}"
    ISO_DATETIME_FORMAT: str = f"{ISO_DATE_FORMAT}{SPLITTER}{SECOND_ZEROS_TIME_FORMAT}"

    DATE_PART_DELIMITER: str = "."
    YEARLESS_DATE_FORMAT: str = f"{DAY_FORMAT}{DATE_PART_DELIMITER}%m"
    DATE_FORMAT: str = f"{YEARLESS_DATE_FORMAT}{DATE_PART_DELIMITER}%Y"
    DAYLESS_DATE_FORMAT: str = f"%m{DATE_PART_DELIMITER}%Y"

    DATETIME_ONLY_HOUR_FORMAT: str = f"{DATE_FORMAT} {HOUR_TIME_FORMAT}"
    DATETIME_SECOND_ZEROS_FORMAT: str = f"{DATE_FORMAT} {SECOND_ZEROS_TIME_FORMAT}"
    DATETIME_FORMAT: str = f"{DATE_FORMAT} {TIME_FORMAT}"
